@@ -3,9 +3,12 @@ import undetected_chromedriver as uc
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
+from selenium.webdriver.common.action_chains import ActionChains
+
+from time import sleep
 
 import os
-from random import choice
+from random import choice, uniform
 
 
 class BrowserV2:
@@ -38,7 +41,7 @@ class BrowserV2:
         if profile_path is not None:
             if not os.path.exists(profile_path):
                 os.makedirs(profile_path)
-            BrowserV2.__options.add_argument("--profile-directory=Default")
+            # BrowserV2.__options.add_argument("--profile-directory=Default")
             BrowserV2.__options.add_argument('--user-data-dir=' + profile_path)
 
         BrowserV2.user_agents = list(Utils.get_agent_users())
@@ -81,6 +84,16 @@ class BrowserV2:
     def input(self, xpath, send):
         self.driver.find_element(By.XPATH, xpath).send_keys(send)
 
+    def input_like_a_human(self, xpath, send):
+        element = self.driver.find_element(By.XPATH, xpath)
+        for character in send:
+            actions = ActionChains(self.driver)
+            actions.move_to_element(element)
+            actions.click()
+            actions.send_keys(character)
+            actions.perform()
+            sleep(uniform(0.01, 0.1))
+
     def get_text(self, xpath):
         return self.driver.find_element(By.XPATH, xpath).text
 
@@ -214,4 +227,3 @@ class Utils:
             'Safari/537.36 '
         )
         return agents
-
